@@ -43,6 +43,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Administración",
     "Owner" : "Dueño",
+    "Groups" : "Grupos",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
@@ -75,7 +76,6 @@ OC.L10N.register(
     "Voice" : "Voz",
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
-    "Manager" : "Gerente",
     "Social network" : "Red social",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
@@ -91,6 +91,7 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Manager" : "Gerente"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
