@@ -6,13 +6,14 @@ OC.L10N.register(
     "Contacts" : "Contactos",
     "Loading contacts …" : "Cargando contactos ...",
     "General settings" : "Configuraciones generales",
-    "Send email" : "Enviar correo electrónico",
-    "Download" : "Descargar",
     "Rename" : "Renombrar",
+    "Send email" : "Enviar correo electrónico",
     "Delete" : "Borrar",
+    "Download" : "Descargar",
     "Copy link" : "Copiar liga",
     "Share with users or groups" : "Compartir con otros usuarios o grupos",
     "can edit" : "puede editar",
+    "Add" : "Agregar",
     "First name" : "Nombre",
     "Last name" : "Apellido",
     "Display name" : "Nombre a desplegar",
@@ -41,7 +42,7 @@ OC.L10N.register(
     "Moderator" : "Moderador",
     "Admin" : "Admin",
     "Owner" : "Dueño",
-    "Users" : "Usuarios",
+    "Groups" : "Grupos",
     "Detailed name" : "Nombre detallado",
     "Additional names" : "Nombres adicionales",
     "Prefix" : "Prefijo",
@@ -74,7 +75,6 @@ OC.L10N.register(
     "Voice" : "Voz",
     "Car" : "Auto",
     "Work pager" : "Localizador de trabajo",
-    "Manager" : "Gerente",
     "Social network" : "Red social",
     "Spouse" : "Cónyuge",
     "Child" : "Hijo",
@@ -93,6 +93,7 @@ OC.L10N.register(
     "Gender" : "Género",
     "Female" : "Femenino",
     "Male" : "Masculino",
-    "Unknown" : "Desconocido"
+    "Unknown" : "Desconocido",
+    "Manager" : "Gerente"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
