@@ -11,8 +11,6 @@ OC.L10N.register(
     "Allow updating avatars from social media" : "ソーシャルメディアからのアバターの更新を許可する",
     "Please select a team" : "チームを選択してください",
     "Loading team…" : "チームを読み込み中...",
-    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
-    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "There was an error fetching the member list" : "メンバーリストの取得中にエラーが発生しました",
     "Loading contacts …" : "連絡先を読み込み中...",
     "There are no contacts yet" : "連絡先はまだありません",
@@ -45,6 +43,7 @@ OC.L10N.register(
     "Show all teams" : "すべてのチームを表示",
     "Collapse teams" : "チームを折りたたむ",
     "This group already exists" : "このグループはすでに存在しています",
+    "An error occurred while creating the group" : "グループ作成中にエラーが発生しました",
     "This team already exists" : "このチームはすでに存在しています",
     "An error happened during the creation of the team" : "チームの作成中にエラーが発生しました",
     "{addressbookname} (Disabled)" : "{addressbookname} (無効)",
@@ -99,9 +98,8 @@ OC.L10N.register(
     "Team settings" : "チーム設定",
     "Request to join" : "参加リクエスト",
     "Description" : "詳細",
-    "Members" : "メンバー",
-    "Manage members" : "メンバーの管理",
-    "Team members" : "チームのメンバー",
+    "Your request to join this team is pending approval" : "このチームへの参加リクエストは承認待ちです",
+    "You are not a member of {circle}" : "あなたはサークル{circle}のメンバーではありません",
     "Team resources" : "チームのリソース",
     "Anything shared with this team will show up here" : "このチームと共有されているものはすべてここに表示されます",
     "Team name" : "チーム名",
@@ -124,6 +122,7 @@ OC.L10N.register(
     "Invalid image" : "無効な画像",
     "Error cropping picture" : "画像のトリミング中にエラーが発生しました",
     "Pick an avatar" : "アバターを選択",
+    "Pick" : "選定",
     "Error while processing the picture." : "画像の加工中にエラーが発生しました",
     "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
     "Avatar already up to date" : "アバターはすでに最新です",
@@ -173,11 +172,11 @@ OC.L10N.register(
     "Local team" : "ローカルチーム",
     "This team will not be shared with the other instances of the global scale" : "このチームはグローバルスケールの他のインスタンスと共有されません",
     "Create team" : "チームを作成する",
+    "Team members" : "チームのメンバー",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
     "The list of members is only visible to members of this team" : "メンバーのリストは、このチームのメンバーにのみ表示されます",
     "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
     "Add members" : "メンバーの追加",
-    "Show team details" : "チームの詳細を表示",
     "Add to {circle}" : "{circle} に追加",
     "Unable to get the recommendations list" : "おすすめリストを取得できません",
     "Unable to get the results" : "結果を取得できません",
@@ -207,6 +206,8 @@ OC.L10N.register(
     "Contact not found" : "連絡先がありません",
     "Group {group} not found" : "グループ {group} が見つかりません",
     "Close" : "閉じる",
+    "No data for this contact" : "この連絡先のデータはありません",
+    "No data for this contact on their profile" : "プロフィールにこの連絡先のデータがありません",
     "Import" : "インポート",
     "Are you sure you want to import this contact file?" : "この連絡先ファイルをインポートしますか?",
     "Could not copy" : "コピーできませんでした",
@@ -243,9 +244,11 @@ OC.L10N.register(
     "Team membership" : "チームのメンバー",
     "Prevent teams from being a member of another team" : "チームが別のチームのメンバーになることを禁止する",
     "users" : "ユーザー",
+    "Users" : "ユーザー",
     "groups" : "グループ",
     "teams" : "チーム",
     "email addresses" : "メールアドレス",
+    "Email addresses" : "メールアドレス",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
     "Prefix" : "プレフィックス",
@@ -266,8 +269,10 @@ OC.L10N.register(
     "Postal code" : "郵便番号",
     "Country" : "国名",
     "Birthday" : "誕生日",
+    "Place of birth" : "出身地",
     "Anniversary" : "記念日",
     "Date of death" : "命日",
+    "Place of death" : "死亡場所",
     "Instant messaging" : "インスタントメッセージ",
     "Phone" : "電話番号",
     "Mobile" : "携帯",
@@ -280,6 +285,7 @@ OC.L10N.register(
     "Voice" : "音声番号",
     "Car" : "自動車",
     "Work pager" : "ワークページャー",
+    "Line manager" : "ラインマネージャー",
     "Social network" : "ソーシャルネットワーク",
     "Relationship to you" : "あなたとの関係",
     "Spouse" : "配偶者",
@@ -309,6 +315,9 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "チーム {circleId} を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。",
     "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "メンバーシップは、モデレーターにより確認/承認が必要です（開く要求）",
-    "Manager" : "マネージャー"
+    "Manager" : "マネージャー",
+    "Members" : "メンバー",
+    "Manage members" : "メンバーの管理",
+    "Show team details" : "チームの詳細を表示"
 },
 "nplurals=1; plural=0;");
