@@ -9,7 +9,6 @@ OC.L10N.register(
     "Copy to full name" : "전체 이름으로 복사",
     "Omit year" : "연도 생략",
     "Allow updating avatars from social media" : "소셜 네트워크에서 아바타 업데이트를 허용",
-    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "There was an error fetching the member list" : "회원 목록을 불러오는 중 오류 발생",
     "Loading contacts …" : "연락처 불러오는 중…",
     "There are no contacts yet" : "연락처 없음",
@@ -46,7 +45,6 @@ OC.L10N.register(
     "Renaming of address book was not successful." : "주소록 이름 변경에 실패했습니다.",
     "_%n contact_::_%n contacts_" : ["연락처 %n개"],
     "_%n group_::_%n groups_" : ["그룹 %n개"],
-    "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}명과 공유함"],
     "Share with users or groups" : "사용자 및 그룹과 공유",
     "Share with users" : "사용자와 공유",
     "No users or groups" : "사용자나 그룹 없음",
@@ -77,6 +75,7 @@ OC.L10N.register(
     "Failed to save password. Please try again later." : "암호를 저장하는 데 실패했습니다. 잠시 후 다시 시도하십시오.",
     "Request to join" : "등록 요청",
     "Description" : "설명",
+    "You are not a member of {circle}" : "당신은 {circle}의 회원이 아닙니다.",
     "Settings" : "Settings",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
     "An error happened during name sync" : "이름 동기화 중 오류 발생",
@@ -86,7 +85,6 @@ OC.L10N.register(
     "Crop contact photo" : "연락처 사진 잘라내기",
     "Upload a new picture" : "새 그림 업로드",
     "Choose from Files" : "파일에서 선택",
-    "Get from " : "가져오기 - ",
     "Download picture" : "그림 다운로드",
     "Delete picture" : "그림 삭제",
     "Please select a valid format" : "유효한 형식을 선택하십시오",
@@ -165,11 +163,6 @@ OC.L10N.register(
     "Contact not found" : "연락처를 찾을 수 없음",
     "Group {group} not found" : "그룹 {group}을(를) 찾을 수 없음",
     "Close" : "닫기",
-    "_{success} contact added to {name}_::_{success} contacts added to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
-    "_Adding {success} contact to {name}_::_Adding {success} contacts to {name}_" : ["{success} 연락처를 {name}에 추가하는 중"],
-    "_{count} error_::_{count} errors_" : ["{count} 오류 발생"],
-    "_Importing %n contact into {addressbook}_::_Importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처를 가져오는 중"],
-    "_Done importing %n contact into {addressbook}_::_Done importing %n contacts into {addressbook}_" : ["{addressbook}에 %n 연락처 가져오기 완료"],
     "Import" : "가져오기",
     "Could not copy" : "복사할 수 없음",
     "You are about to leave {circle}.\nAre you sure?" : "{circle} 서클에서 정말 떠나시겠습니까?",
@@ -193,6 +186,7 @@ OC.L10N.register(
     "Members can also invite" : "회원도 초대 가능",
     "Visibility" : "표시 여부",
     "Visible to everyone" : "모두에게 보이기",
+    "Email addresses" : "이메일 주소",
     "Detailed name" : "자세한 이름",
     "Additional names" : "추가 이름",
     "Prefix" : "접두사",
@@ -227,7 +221,6 @@ OC.L10N.register(
     "Voice" : "음성 번호",
     "Car" : "카폰",
     "Work pager" : "직장 호출기",
-    "Manager" : "관리자",
     "Social network" : "소셜 네트워크",
     "Relationship to you" : "나와의 관계",
     "Spouse" : "배우자",
@@ -252,6 +245,8 @@ OC.L10N.register(
     "Time zone" : "시간대",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Unable to delete contact" : "연락처를 삭제할 수 없음"
+    "Unable to delete contact" : "연락처를 삭제할 수 없음",
+    "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "중재자가 회원 가입을 확인 및 수락해야 합니다. (요청 가능)",
+    "Manager" : "관리자"
 },
 "nplurals=1; plural=0;");
