@@ -9,15 +9,19 @@ OC.L10N.register(
     "Copy to full name" : "复制到全名",
     "Omit year" : "忽略年份",
     "Allow updating avatars from social media" : "允许从社交媒体资料更新头像",
-    "You are not a member of {circle}" : "您并非 {circle} 的成员",
+    "Please select a team" : "请选择团队",
+    "Loading team…" : "正在加载团队…",
     "There was an error fetching the member list" : "获取成员列表时发生一个错误",
     "Loading contacts …" : "正在加载联系人 ...",
     "There are no contacts yet" : "尚无联系人",
     "Create contact" : "创建联系人",
-    "There are no contacts in this group" : "该群组中没有联系人",
+    "There are no contacts in this group" : "此群组中没有联系人",
     "Create contacts" : "新建联系人",
     "Add contacts" : "添加联系人",
     "Loading …" : "正在加载…",
+    "Manage team" : "管理团队",
+    "Leave team" : "离开团队",
+    "Delete team" : "删除团队",
     "Contacts settings" : "联系人设置",
     "General settings" : "一般设置",
     "Update avatars from social media" : "从社交媒体更新头像",
@@ -31,19 +35,30 @@ OC.L10N.register(
     "Contact groups" : "联系人群组",
     "Create a new contact group" : "创建联系人群组",
     "Contact group name" : "联系人群组名称",
+    "Teams" : "团队",
     "Create a new team" : "创建新团队",
-    "Show all groups" : "显示所有小组",
-    "Collapse groups" : "折叠小组",
-    "This group already exists" : "该群组已存在",
+    "Open the contacts app settings" : "打开联系人应用设置",
+    "Show all groups" : "显示全部群组",
+    "Collapse groups" : "收起群组",
+    "Show all teams" : "显示全部团队",
+    "Collapse teams" : "收起团队",
+    "Group name cannot be empty" : "群组名称不能为空",
+    "This group already exists" : "此群组已存在",
+    "An error occurred while creating the group" : "创建群组时出错",
+    "This team already exists" : "此团队已存在",
+    "An error happened during the creation of the team" : "创建团队时出错",
     "{addressbookname} (Disabled)" : "{addressbookname}（已停用）",
     "Download" : "下载",
     "Show" : "显示",
+    "Unshare from me" : "我取消的共享",
     "Copied" : "已复制",
     "Cannot copy" : "无法复制",
     "Copy link" : "复制链接",
     "Toggling of address book was not successful" : "通讯录切换不成功",
     "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
     "Delete {addressbook}?" : "删除 {addressbook} ？",
+    "This will unshare the address book and every contacts within it" : "这将取消共享通讯录及其中的每位联系人",
+    "Unshare {addressbook}?" : "取消共享 {addressbook}？ ",
     "Deletion of address book was not successful." : "通讯录删除不成功",
     "Renaming of address book was not successful." : "通讯录重命名不成功",
     "_%n contact_::_%n contacts_" : ["%n 位联系人"],
@@ -61,7 +76,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "导入已被禁用，因为没有可用的地址簿",
     "Choose a vCard file to import" : "选择要导入的 vCard（电子名片） 文件",
     "Add new address book" : "添加新通讯录",
-    "Add" : "Add",
+    "Add" : "添加",
     "An error occurred, unable to create the address book" : "发生错误，无法创建通讯录",
     "First name" : "名",
     "Last name" : "姓",
@@ -74,19 +89,25 @@ OC.L10N.register(
     "Oversees" : "监督",
     "An error happened during the config change" : "更改配置时发生一个错误",
     "Password protection" : "密码保护",
+    "Enforce password protection on files shared to this team" : "对与此团队共享的文件强制实施密码保护",
+    "Use a unique password for all shares to this team" : "为此团队的全部共享使用唯一密码",
     "Unique password …" : "独立密码 ...",
     "Save" : "保存",
     "Change unique password" : "修改独立密码",
     "Failed to save password. Please try again later." : "保存密码失败，请稍后重试。",
+    "Team owned by {owner}" : "{owner} 拥有的团队",
     "Team settings" : "团队设置",
     "Request to join" : "请求加入",
     "Description" : "描述",
-    "Members" : "成员",
-    "Manage members" : "管理成员",
-    "Team members" : "团队成员",
+    "Your request to join this team is pending approval" : "您加入此团队的请求正在等待批准",
+    "You are not a member of {circle}" : "您并非 {circle} 的成员",
     "Team resources" : "团队资源",
+    "Anything shared with this team will show up here" : "与此团队共享的任何内容都将显示在此处",
     "Team name" : "团队名称",
-    "Settings" : "Settings",
+    "Settings" : "设置",
+    "Actions" : "操作",
+    "There is no description for this team" : "此团队没有描述",
+    "Enter a description for the team" : "输入团队的描述",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
     "Cancel" : "取消",
@@ -102,6 +123,7 @@ OC.L10N.register(
     "Invalid image" : "无效的图像",
     "Error cropping picture" : "裁剪照片时发生错误",
     "Pick an avatar" : "选择一个头像",
+    "Pick" : "选择",
     "Error while processing the picture." : "处理图片时出错。",
     "Avatar downloaded from social network" : "已从社交媒体下载头像",
     "Avatar already up to date" : "头像已是最新",
@@ -146,13 +168,21 @@ OC.L10N.register(
     "Add to group" : "添加到群组",
     "Add {type}" : "添加  {type}",
     "New team name" : "新团队名称",
+    "Personal team" : "个人团队",
+    "This team will only be visible to you. Other members will not be able to see or use it." : "此团队仅对您可见，其他成员将无法看到或使用它。",
+    "Local team" : "本地团队",
+    "This team will not be shared with the other instances of the global scale" : "此团队不会与全局范围内的其他实例共享",
+    "Create team" : "创建团队",
+    "Team members" : "团队成员",
     "Loading members list …" : "正在加载成员列表 ...",
+    "The list of members is only visible to members of this team" : "成员列表仅对此团队的成员可见",
     "You currently have no access to the member list" : "您目前无法访问成员列表",
     "Add members" : "添加成员",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "无法获取推荐列表",
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
+    "There was an issue adding members to the team" : "向团队添加成员时出现问题",
     "Accept membership request" : "接受成员身份请求",
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
@@ -175,22 +205,30 @@ OC.L10N.register(
     "New contact" : "新建联系人",
     "Unable to create the contact." : "未能成功创建联系人。",
     "Contact not found" : "未找到联系人",
-    "Group {group} not found" : "未找到小组 {group} ",
+    "Group {group} not found" : "未找到群组 {group} ",
     "Close" : "关闭",
+    "No data for this contact" : "此联系人无数据",
+    "No data for this contact on their profile" : "此联系人的个人资料中没有相关数据",
     "Import" : "导入",
     "Are you sure you want to import this contact file?" : "您确定您想要导入此联系人文件吗？",
     "Could not copy" : "无法复制",
+    "Join team" : "加入团队",
     "You are about to leave {circle}.\nAre you sure?" : "您即将离开 {circle}\n确定吗？",
+    "Please confirm team leave" : "请确认离开团队 ",
     "Could not leave the team {displayName}" : "无法离开团队 {显示名称}",
+    "Unable to join the team" : "无法加入团队",
     "You are about to delete {circle}.\nAre you sure?" : "您即将删除 {circle}\n确定吗？",
+    "Please confirm team deletion" : "请确认删除团队",
+    "Unable to delete the team" : "无法删除团队",
     "Link copied to the clipboard" : "链接已复制到剪贴板",
     "Could not copy link to the clipboard." : "无法复制链接到剪贴板",
     "Not grouped" : "未分组",
     "Recently contacted" : "最近联系",
     "Organization chart" : "组织图",
     "Teams are groups of people that you can create yourself and with whom you can share data. They can be made up of other accounts or groups of accounts of the Nextcloud instance, but also of contacts from your address book or even external people by simply entering their e-mail addresses." : "团队是一群人，你可以自己创建，也可以与他们共享数据。它们可以由 Nextcloud 实例的其它账号或账号组组成，也可以由通讯录中的联系人组成，甚至可以由外部人员组成，只需输入他们的电子邮箱地址即可。",
+    "Team" : "团队",
     "User" : "用户",
-    "Group" : "小组",
+    "Group" : "群组",
     "Email" : "电子邮件",
     "Contact" : "联系人",
     "Member" : "成员",
@@ -200,10 +238,20 @@ OC.L10N.register(
     "Invites" : "邀请",
     "Anyone can request membership" : "任何人均可请求成员资格",
     "Members need to accept invitation" : "成员需要接受邀请",
+    "Memberships must be confirmed/accepted by a Moderator (requires \"Anyone can request membership\")" : "成员资格必须由主持人确认/接受（要求“任何人都可以申请成员资格”）",
     "Members can also invite" : "成员也可以邀请",
     "Visibility" : "可见性",
     "Visible to everyone" : "对所有人可见",
     "Team membership" : "团队成员",
+    "Prevent teams from being a member of another team" : "防止团队成为其他团队的成员",
+    "users" : "用户",
+    "Users" : "用户",
+    "groups" : "群组",
+    "Groups" : "群组",
+    "teams" : "团队",
+    "email addresses" : "电子邮件地址",
+    "Email addresses" : "电子邮件地址",
+    "contacts" : "联系人",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
     "Prefix" : "前缀",
@@ -224,8 +272,10 @@ OC.L10N.register(
     "Postal code" : "邮政编码",
     "Country" : "国家",
     "Birthday" : "生日",
+    "Place of birth" : "出生地",
     "Anniversary" : "周年",
     "Date of death" : "去世日期",
+    "Place of death" : "死亡地",
     "Instant messaging" : "即时通讯",
     "Phone" : "电话",
     "Mobile" : "手机",
@@ -238,6 +288,7 @@ OC.L10N.register(
     "Voice" : "语音",
     "Car" : "车",
     "Work pager" : "工作传呼机",
+    "Line manager" : "部门经理",
     "Social network" : "社交网络",
     "Relationship to you" : "和您的关系",
     "Spouse" : "配偶",
@@ -262,9 +313,14 @@ OC.L10N.register(
     "Time zone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
     "Unable to create team {circleName}" : "无法创建团队 {圈子名称}",
+    "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
     "Unable to delete contact" : "无法删除联系人",
     "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "成员资格必须由一名主持人确认/接受（必须为开放圈子）",
-    "Manager" : "经理"
+    "Manager" : "经理",
+    "Members" : "成员",
+    "Manage members" : "管理成员",
+    "Show team details" : "显示团队详情"
 },
 "nplurals=1; plural=0;");
