@@ -11,8 +11,6 @@ OC.L10N.register(
     "Allow updating avatars from social media" : "允許從社群媒體更新虛擬化身大頭照",
     "Please select a team" : "請選取團隊",
     "Loading team…" : "正在加載團隊 …",
-    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
-    "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "There was an error fetching the member list" : "擷取成員清單出錯",
     "Loading contacts …" : "正在載入通訊錄 …",
     "There are no contacts yet" : "目前沒有聯絡人",
@@ -44,6 +42,7 @@ OC.L10N.register(
     "Collapse groups" : "收合群組",
     "Show all teams" : "顯示所有團隊",
     "Collapse teams" : "折疊團隊",
+    "Group name cannot be empty" : "群組名稱不能為空的",
     "This group already exists" : "該群組已存在",
     "An error occurred while creating the group" : "建立群組時發生錯誤",
     "This team already exists" : "此團隊已存在",
@@ -77,7 +76,7 @@ OC.L10N.register(
     "Importing is disabled because there are no address books available" : "已停用導入，因為沒有可用的通訊錄",
     "Choose a vCard file to import" : "選取要導入的 vCard 檔案",
     "Add new address book" : "添加新通訊錄",
-    "Add" : "加入",
+    "Add" : "添加",
     "An error occurred, unable to create the address book" : "發生錯誤，無法建立通訊錄",
     "First name" : "名",
     "Last name" : "姓",
@@ -100,9 +99,8 @@ OC.L10N.register(
     "Team settings" : "團隊設定",
     "Request to join" : "請求加入",
     "Description" : "描述",
-    "Members" : "成員",
-    "Manage members" : "管理成員",
-    "Team members" : "團隊成員",
+    "Your request to join this team is pending approval" : "您加入此團隊的請求正在等待批准",
+    "You are not a member of {circle}" : "您不是 {circle} 的成員",
     "Team resources" : "團隊資源",
     "Anything shared with this team will show up here" : "與此團隊分享的任何東西都會顯示在此處",
     "Team name" : "團隊名字",
@@ -175,11 +173,11 @@ OC.L10N.register(
     "Local team" : "本地團隊",
     "This team will not be shared with the other instances of the global scale" : "此團隊不會與全球範圍內的其他實例共享",
     "Create team" : "創建團隊",
+    "Team members" : "團隊成員",
     "Loading members list …" : "正在加載成員清單 …",
     "The list of members is only visible to members of this team" : "成員清單僅有此團隊的成員可見",
     "You currently have no access to the member list" : "您目前無權存取會員清單",
     "Add members" : "添加成員",
-    "Show team details" : "顯示團隊詳細資訊",
     "Add to {circle}" : "添加到 {circle}",
     "Unable to get the recommendations list" : "無法獲取推薦列表",
     "Unable to get the results" : "無法得到結果",
@@ -209,6 +207,8 @@ OC.L10N.register(
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
     "Close" : "關閉",
+    "No data for this contact" : "此聯絡人沒有數據資料",
+    "No data for this contact on their profile" : "此聯絡人的個人檔案中沒有數據資料",
     "Import" : "導入",
     "Are you sure you want to import this contact file?" : "您確定您想要匯入此聯絡人檔案嗎？",
     "Could not copy" : "無法複製",
@@ -245,9 +245,13 @@ OC.L10N.register(
     "Team membership" : "團隊成員身分",
     "Prevent teams from being a member of another team" : "防止團隊成為另一個團隊的成員",
     "users" : "用戶",
+    "Users" : "用戶",
     "groups" : "群組",
+    "Groups" : "群組",
     "teams" : "團隊",
     "email addresses" : "電郵地址",
+    "Email addresses" : "電郵地址",
+    "contacts" : "聯絡人",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
@@ -314,6 +318,9 @@ OC.L10N.register(
     "Unable to delete team {circleId}" : "無法刪除團隊 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人",
     "Memberships must be confirmed/accepted by a Moderator (requires Open)" : "會員資格必須由版主確認/接受（需要開放）",
-    "Manager" : "經理"
+    "Manager" : "經理",
+    "Members" : "成員",
+    "Manage members" : "管理成員",
+    "Show team details" : "顯示團隊詳細資訊"
 },
 "nplurals=1; plural=0;");
